/* Reflow Oven Controller
*
* Copyright (C) 2020  Mario Hüttel <mario.huettel@gmx.net>
*
* This file is part of the Reflow Oven Controller Project.
*
* The reflow oven controller is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License version 2 as
* published by the Free Software Foundation.
*
* The Reflow Oven Control Firmware is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with the reflow oven controller project.
* If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SETTINGS_SETTINGS_SD_CARD_H__
#define __SETTINGS_SETTINGS_SD_CARD_H__

#include <stdbool.h>
#include <reflow-controller/settings/settings.h>

/**
 * @brief Save the calibration to the SD card
 * @param sens_deviation Sensitivity deviation from nomila sensitivity (1)
 * @param offset Offset
 * @param active Calibration is active. If false, the calibration will be deleted from SD card
 * @return 0 if successful
 */
int sd_card_settings_save_calibration(float sens_deviation, float offset, bool active);

/**
 * @brief Try and load calibration from SD card
 * @param sens_deviation
 * @param offset
 * @return 0 if files found -1 if files errorneous, -2 if no files found
 */
int sd_card_settings_try_load_calibration(float *sens_deviation, float *offset);

/**
 * @brief Load the PID parameters from @ref SETTINGS_PID_PARAMETER_FILE
 * @param settings The PID settings
 * @return Load result.
 * @note This function is currently not used for the temperature profiles. They implement the PID parameters directy
 * inside the profile
 */
enum settings_load_result sd_card_settings_load_pid_oven_parameters(struct oven_pid_settings *settings);

#endif /* __SETTINGS_SETTINGS_SD_CARD_H__ */
